@@ -38,7 +38,7 @@ class DockerApplication(object):
     MediaWiki Docker image
     '''
 
-    def __init__(self,user:str,password:str,name="mediawiki",version="1.35.2",extensionMap:dict={},wikiId:str=None,mariaDBVersion="10.5",smwVersion=None,logo=None,port=9080,sqlPort=9306,mySQLRootPassword=None,debug=False,verbose=True):
+    def __init__(self,user:str,password:str,name="mediawiki",version="1.35.5",extensionMap:dict={},wikiId:str=None,mariaDBVersion="10.6",smwVersion=None,logo=None,port=9080,sqlPort=9306,mySQLRootPassword=None,debug=False,verbose=True):
         '''
         Constructor
         
@@ -266,7 +266,7 @@ class DockerApplication(object):
                 print (f"Connection to {self.database} on {self.host} with user {self.dbUser} established database returns: {rows[0]}")
         return ok
     
-    def checkDBConnection(self,timeout:float=10,initialSleep:float=2.5,maxTries:int=6)->bool:
+    def checkDBConnection(self,timeout:float=10,initialSleep:float=2.5,maxTries:int=7)->bool:
         '''
         check database connection with retries
         
@@ -333,6 +333,8 @@ class DockerApplication(object):
         requires=[]
         for ext in self.extensionMap.values():
             if hasattr(ext,"composer"):
+                # get the composer statement
+                composer=ext.composer
                 requires.append(ext.composer)
         indent="     "
         delim="" if len(requires)==0 else ",\n"
